@@ -234,23 +234,14 @@ class FullTextSearch(object):
 
     def _do_search(self, sort_by=None):
         si = SolrInterface(self.solr_endpoint)
-        query = si.query().field_limit(score=True)
 
-        for searchterm in self.searchable:
-            query = query.query(searchterm)
+        searchquery = si.Q(*[si.Q(s) for s in self.searchable])
+        query = si.query(searchquery).field_limit(score=True)
 
         realm_query = self._build_realm_filter(si)
         if realm_query:
             query = query.filter(realm_query)
 
-        # boosting
-        query = query.boost_relevancy(5, realm="ticket")\
-                     .boost_relevancy(5, status="new")\
-                     .boost_relevancy(5, status="assigned")\
-                     .boost_relevancy(10, status="reopened")\
-                     .boost_relevancy(3, status="reviewing")\
-                     .boost_relevancy(5, status="accepted")
-
         author_query = self._build_author_filter(si)
         if author_query:
             query = query.filter(author_query)
@@ -262,34 +253,20 @@ class FullTextSearch(object):
         for field in sort_by or []:
             query = query.sort_by(field)
 
-        return query.paginate(start=self.page_start, rows=self.page_size)\
+        query = query.paginate(start=self.page_start, rows=self.page_size)\
                             .highlight('oneline',
                                     **{'simple.pre':'<span class="highlight">',
                                        'snippets': 3,
-                                       'simple.post':'</span>'})\
-                            .highlight('title',
-                                    **{'simple.pre':'<span class="highlight">',
-                                       'simple.post':'</span>'})\
-                            .execute()
+                                       'fragsize': 600,
+                                       'simple.post':'</span>'})
 
-    def _docs(self, query):
-        """Return a generator of all the docs in query.
-        """
-        i = 0
-        while True:
-            response = query.paginate(start=i, rows=self.page_size)\
-                            .highlight('oneline',
-                                    **{'simple.pre':'<span class="highlight">',
-                                       'simple.post':'</span>'})\
-                            .highlight('title',
-                                    **{'simple.pre':'<span class="highlight">',
-                                       'simple.post':'</span>'})\
-                            .execute()
-            for doc in response:
-                yield doc
-            if len(response) < self.page_size:
-                break
-            i += self.page_size
+        # boosting - super hacky but sunburnt is not support bq
+        options = query.options()
+        options['bq'] = ['realm:ticket^999','status:new^100', 'status:assigned^100',
+                         'status:reopened^999', 'status:reviewing^100',
+                         'status:accepted^100','(*:* -xxx)^999']
+        result = query.interface.search(**options)
+        return query.transform_result(result, dict)
 
 
 class FullTextSearchObject(object):
